import pathlib
from setuptools import setup, find_packages

HERE = pathlib.Path(__file__).parent

VERSION = '0.11.6'
PACKAGE_NAME = 'px-device-identity-service'
AUTHOR = 'Franz Geffke'
AUTHOR_EMAIL = 'franz@pantherx.org'
URL = 'https://git.pantherx.org/development/applications/px-device-identity-service'

LICENSE = 'MIT'
DESCRIPTION = 'Provides access to device signing capabilities via REST API.'
LONG_DESCRIPTION = (HERE / "README.md").read_text()
LONG_DESC_TYPE = "text/markdown"

INSTALL_REQUIRES = [
    'flask',
    'pyyaml',
    'waitress',
    'werkzeug',
    "px-device-identity @ https://source-git-pantherx-org.s3.eu-central-1.amazonaws.com/px-device-identity_latest.tgz",
]

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type=LONG_DESC_TYPE,
    author=AUTHOR,
    license=LICENSE,
    author_email=AUTHOR_EMAIL,
    url=URL,
    install_requires=INSTALL_REQUIRES,
    entry_points={
        'console_scripts': ['px-device-identity-service=px_device_identity_service.main:main'],
    },
    packages=find_packages(),
    zip_safe=False
)
